Welcome to ClientVPS Mirrors

Help for package ical
Type: Package
Title: 'iCalendar' Parsing
Version: 0.1.6
Date: 2019-01-21
Maintainer: Peter Meissner <retep.meissner@gmail.com>
Description: A simple wrapper around the 'ical.js' library executing 'Javascript' code via 'V8' (the 'Javascript' engine driving the 'Chrome' browser and 'Node.js' and accessible via the 'V8' R package). This package enables users to parse 'iCalendar' files ('.ics', '.ifb', '.iCal', '.iFBf') into lists and 'data.frames' to ultimately do statistics on events, meetings, schedules, birthdays, and the like.
License: MIT + file LICENSE
Encoding: UTF-8
LazyData: true
RoxygenNote: 6.1.1
Imports: V8 (≥ 1.5)
Suggests: testthat, covr
NeedsCompilation: no
Packaged: 2019-01-21 20:06:05 UTC; peter
Author: Peter Meissner [aut, cre], Philipp Kewisch [cph] (Ical.js file is is licences under MPL. Source: https://github.com/mozilla-comm/ical.js)
Repository: CRAN
Date/Publication: 2019-01-21 20:20:03 UTC

ical_clean_ical_parsed

Description

ical_clean_ical_parsed

Usage

ical_clean_ical_parsed(ical_parsed)

Arguments

ical_parsed

data provided by ical_parse()


ical_parse

Description

Parses iCalendar format from character vector or file and returns it as a list of columns.

Parses iCalendar format from character vector or file and returns it as data.frame.

Parses iCalendar format from character vector or file and returns it as a list of entries.

Usage

ical_parse(file = NULL, text = NULL)

ical_parse_df(file = NULL, text = NULL)

ical_parse_list(file = NULL, text = NULL)

Arguments

file

path to file to be read in and parsed

text

text of ical file

Examples


# parse from character vector
char_vec <- readLines(system.file("birthdays.ics", package = "ical"))
ical_parse(text = char_vec)

# parse from file
ical_parse(file = system.file("birthdays.ics", package = "ical"))


env$v8 ...

Description

An environment containing bindings to an V8 instance for evaluating JS code.

Usage

v8_env

Format

An object of class environment of length 1.

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.